@@ -102,26 +102,33 @@ hrm.test.matrices <- function(data, alpha=0.05){
 #' @param formula formula object from the user input
 #' @return Returns a data frame consisting of the degrees of freedom, the test value, the critical value and the p-value
 #' @keywords internal
-hrm.test.2.one <- function(X, alpha, group , factor1, subject, data, testing = rep(1,4), formula, nonparametric ){
+hrm.test.2.one <- function(X, alpha, group , factor1, subject, data, testing = rep(1,4), formula, nonparametric, np.correction ){
 
   ranked <- NULL
   varQGlobal <- NULL
+  means <- NULL
+  correction <- NULL
+  tmpQ1g <- NULL
+  tmpQ2g <- NULL
 
-  temp0 <- if(testing[1]) {hrm.1w.1f(X, alpha, group , factor1,  subject, data, "A", paste(as.character(group), " (weighted)"), nonparametric, ranked, varQGlobal)}
-  temp1 <- if(testing[2]) {hrm.1w.1f(X, alpha, group , factor1,  subject, data, "Au", paste(as.character(group)), nonparametric, ranked, varQGlobal)}
-  temp2 <- if(testing[3]) {hrm.1w.1f(X, alpha, group , factor1,  subject, data, "B", paste(as.character(factor1)), nonparametric, ranked, varQGlobal)}
-  temp3 <- if(testing[4]) {hrm.1w.1f(X, alpha, group , factor1, subject, data, "AB", paste(as.character(group), ":",as.character(factor1)), nonparametric, ranked, varQGlobal)}
-  temp4 <- if(testing[3] & (testing[1] | testing[2])) {hrm.1w.1f(X, alpha, group , factor1, subject, data, "A|B", paste(as.character(group), "|",as.character(factor1)), nonparametric, ranked, varQGlobal)}
+  temp0 <- if(testing[1]) {hrm.1w.1f(X, alpha, group , factor1,  subject, data, "A", paste(as.character(group), " (weighted)"), nonparametric, ranked, varQGlobal, np.correction, tmpQ1g, tmpQ2g)}
+  temp1 <- if(testing[2]) {hrm.1w.1f(X, alpha, group , factor1,  subject, data, "Au", paste(as.character(group)), nonparametric, ranked, varQGlobal, np.correction, tmpQ1g, tmpQ2g)}
+  temp2 <- if(testing[3]) {hrm.1w.1f(X, alpha, group , factor1,  subject, data, "B", paste(as.character(factor1)), nonparametric, ranked, varQGlobal, np.correction, tmpQ1g, tmpQ2g)}
+  temp3 <- if(testing[4]) {hrm.1w.1f(X, alpha, group , factor1, subject, data, "AB", paste(as.character(group), ":",as.character(factor1)), nonparametric, ranked, varQGlobal, np.correction, tmpQ1g, tmpQ2g)}
+  temp4 <- if(testing[3] & (testing[1] | testing[2])) {hrm.1w.1f(X, alpha, group , factor1, subject, data, "A|B", paste(as.character(group), "|",as.character(factor1)), nonparametric, ranked, varQGlobal, np.correction, tmpQ1g, tmpQ2g)}
+  #temp5 <- if(testing[3] & (testing[1] | testing[2])) {hrm.1w.1f(X, alpha, group , factor1, subject, data, "B|A", paste(as.character(factor1), "|",as.character(group)), nonparametric, ranked, varQGlobal, np.correction)}
 
   output <- list()
-  output$result <- rbind(temp0, temp1, temp2, temp3,temp4)
+  output$result <- rbind(temp0, temp1, temp2, temp3, temp4)
   output$formula <- formula
   output$alpha <- alpha
   output$subject <- subject
   output$factors <- list(c(group), c(factor1))
   output$data <- X
+  output$mean <- means
   output$var <- varQGlobal
   output$nonparametric <- nonparametric
+  output$np.correction <- correction
   class(output) <- "HRM"
   rownames(output$result) <- 1:dim(output$result)[1]
   return (output)
@@ -140,16 +147,17 @@ hrm.test.2.one <- function(X, alpha, group , factor1, subject, data, testing = r
 #' @param formula formula object from the user input
 #' @return Returns a data frame consisting of the degrees of freedom, the test value, the critical value and the p-value
 #' @keywords internal
-hrm.test.2.within <- function(X, alpha, group , factor1, factor2, subject, data, testing = rep(1,7), formula, nonparametric ){
+hrm.test.2.within <- function(X, alpha, group , factor1, factor2, subject, data, testing = rep(1,7), formula, nonparametric, np.correction ){
 
   ranked <- NULL
   varQGlobal <- NULL
+  correction <- NULL
 
   # create list for storing results; NULL used, because it is ignored by rbind
-  temp <- list(NULL, NULL, NULL, NULL, NULL, NULL, NULL)
+  temp <- vector("list", length = 7)
   for(i in 1:7){
     if(testing[i]) {
-      temp[[i]] <- hrm.1w.2f(X, alpha, group , factor1, factor2, subject, data, H = i, "", nonparametric, ranked, varQGlobal )
+      temp[[i]] <- hrm.1w.2f(X, alpha, group , factor1, factor2, subject, data, H = i, "", nonparametric, ranked, varQGlobal, np.correction )
     }
   }
 
@@ -162,6 +170,8 @@ hrm.test.2.within <- function(X, alpha, group , factor1, factor2, subject, data,
   output$data <- X
   output$var <- varQGlobal
   output$nonparametric <- nonparametric
+  output$np.correction <- correction
+  rownames(output$result) <- 1:dim(output$result)[1]
   class(output) <- "HRM"
 
   return (output)
@@ -182,16 +192,19 @@ hrm.test.2.within <- function(X, alpha, group , factor1, factor2, subject, data,
 #' @param formula formula object from the user input
 #' @return Returns a data frame consisting of the degrees of freedom, the test value, the critical value and the p-value
 #' @keywords internal
-hrm.test.2.between <- function(X, alpha, group , subgroup, factor, subject, data, testing = rep(1,7), formula, nonparametric ){
+hrm.test.2.between <- function(X, alpha, group , subgroup, factor, subject, data, testing = rep(1,7), formula, nonparametric, np.correction ){
 
   ranked <- NULL
   varQGlobal <- NULL
+  correction <- NULL
+  tmpQ1g <- NULL
+  tmpQ2g <- NULL
 
   # create list for storing results; NULL used, because it is ignored by rbind
   temp <- list(NULL, NULL, NULL, NULL, NULL, NULL, NULL)
   for(i in 1:7){
     if(testing[i]) {
-      temp[[i]] <- hrm.2w.1f(X, alpha, group , subgroup, factor, subject, data, H = i, "", nonparametric, ranked, varQGlobal )
+      temp[[i]] <- hrm.2w.1f(X, alpha, group , subgroup, factor, subject, data, H = i, "", nonparametric, ranked, varQGlobal, np.correction, tmpQ1g, tmpQ2g )
     }
   }
 
@@ -204,6 +217,8 @@ hrm.test.2.between <- function(X, alpha, group , subgroup, factor, subject, data
   output$data <- X
   output$var <- varQGlobal
   output$nonparametric <- nonparametric
+  output$np.correction <- correction
+  rownames(output$result) <- 1:dim(output$result)[1]
   class(output) <- "HRM"
 
   return (output)
@@ -224,16 +239,17 @@ hrm.test.2.between <- function(X, alpha, group , subgroup, factor, subject, data
 #' @param formula formula object from the user input
 #' @return Returns a data frame consisting of the degrees of freedom, the test value, the critical value and the p-value
 #' @keywords internal
-hrm.test.2.between.within <- function(X, alpha, group , subgroup, factor1, factor2, subject, data, testing = rep(1,15), formula, nonparametric ){
+hrm.test.2.between.within <- function(X, alpha, group , subgroup, factor1, factor2, subject, data, testing = rep(1,15), formula, nonparametric, np.correction ){
 
   ranked <- NULL
   varQGlobal <- NULL
+  correction <- NULL
 
   # create list for storing results; NULL used, because it is ignored by rbind
   temp <- list(NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL)
   for(i in 1:15){
     if(testing[i]) {
-      temp[[i]] <- hrm.2w.2f(X, alpha, group , subgroup, factor1, factor2, subject, data, H = i, "", nonparametric, ranked, varQGlobal )
+      temp[[i]] <- hrm.2w.2f(X, alpha, group , subgroup, factor1, factor2, subject, data, H = i, "", nonparametric, ranked, varQGlobal, np.correction )
     }
   }
   output <- list()
@@ -245,6 +261,8 @@ hrm.test.2.between.within <- function(X, alpha, group , subgroup, factor1, facto
   output$data <- X
   output$var <- varQGlobal
   output$nonparametric <- nonparametric
+  output$np.correction <- correction
+  rownames(output$result) <- 1:dim(output$result)[1]
   class(output) <- "HRM"
   return (output)
 }
@@ -264,26 +282,27 @@ hrm.test.2.between.within <- function(X, alpha, group , subgroup, factor1, facto
 #' @param formula formula object from the user input
 #' @return Returns a data frame consisting of the degrees of freedom, the test value, the critical value and the p-value
 #' @keywords internal
-hrm.test.3.between <- function(X, alpha, group , factor1, factor2, factor3, subject, data, testing = rep(1,15), formula, nonparametric ){
+hrm.test.3.between <- function(X, alpha, group , factor1, factor2, factor3, subject, data, testing = rep(1,15), formula, nonparametric, np.correction ){
 
   ranked <- NULL
   varQGlobal <- NULL
+  correction <- NULL
 
-  temp0 <- if(testing[1]) {hrm.1w.3f(X, alpha, group, factor1, factor2, factor3, subject, data, "P", "J", "J", "J",  paste(as.character(group) ), nonparametric, ranked,varQGlobal )}
-  temp1 <- if(testing[2]) {hrm.1w.3f(X, alpha, group, factor1, factor2, factor3,  subject, data, "J", "P", "J", "J", paste(as.character(factor1)), nonparametric, ranked,varQGlobal )}
-  temp2 <- if(testing[3]) {hrm.1w.3f(X, alpha, group, factor1, factor2, factor3,  subject, data, "J", "J", "P", "J", paste(as.character(factor2)), nonparametric, ranked,varQGlobal )}
-  temp3 <- if(testing[4]) {hrm.1w.3f(X, alpha, group, factor1, factor2, factor3,  subject, data, "J", "J", "J", "P", paste(as.character(factor3)), nonparametric, ranked,varQGlobal )}
-  temp4 <- if(testing[5]) {hrm.1w.3f(X, alpha, group, factor1, factor2, factor3,  subject, data, "P", "P", "J", "J", paste(as.character(group),":",as.character(factor1)), nonparametric, ranked,varQGlobal )}
-  temp5 <- if(testing[6]) {hrm.1w.3f(X, alpha, group, factor1, factor2, factor3,  subject, data, "P", "J", "P", "J", paste(as.character(group),":",as.character(factor2)), nonparametric, ranked,varQGlobal )}
-  temp6 <- if(testing[7]) {hrm.1w.3f(X, alpha, group, factor1, factor2, factor3,  subject, data, "P", "J", "J", "P", paste(as.character(group),":",as.character(factor3)), nonparametric, ranked,varQGlobal )}
-  temp7 <- if(testing[8]) {hrm.1w.3f(X, alpha, group, factor1, factor2, factor3,  subject, data, "J", "P", "P", "J", paste(as.character(factor1),":",as.character(factor2)), nonparametric, ranked,varQGlobal )}
-  temp8 <- if(testing[9]) {hrm.1w.3f(X, alpha, group, factor1, factor2, factor3,  subject, data, "J", "P", "J", "P", paste(as.character(factor1),":",as.character(factor3)), nonparametric, ranked,varQGlobal )}
-  temp9 <- if(testing[10]) {hrm.1w.3f(X, alpha, group, factor1, factor2, factor3,  subject, data, "J", "J", "P", "P",paste(as.character(factor2),":",as.character(factor3)), nonparametric, ranked,varQGlobal )}
-  temp10 <- if(testing[11]) {hrm.1w.3f(X, alpha, group, factor1, factor2, factor3,  subject, data, "P", "P", "P", "J", paste(as.character(group),":",as.character(factor1), ":", as.character(factor2)), nonparametric, ranked,varQGlobal )}
-  temp11 <- if(testing[12]) {hrm.1w.3f(X, alpha, group, factor1, factor2, factor3,  subject, data, "P", "P", "J", "P", paste(as.character(group),":",as.character(factor1), ":", as.character(factor3)), nonparametric, ranked,varQGlobal )}
-  temp12 <- if(testing[13]) {hrm.1w.3f(X, alpha, group, factor1, factor2, factor3,  subject, data, "P", "J", "P", "P", paste(as.character(group),":",as.character(factor2), ":", as.character(factor3)), nonparametric, ranked,varQGlobal )}
-  temp13 <- if(testing[14]) {hrm.1w.3f(X, alpha, group, factor1, factor2, factor3,  subject, data, "J", "P", "P", "P", paste(as.character(factor1),":",as.character(factor2), ":", as.character(factor3)), nonparametric, ranked,varQGlobal )}
-  temp14 <- if(testing[15]) {hrm.1w.3f(X, alpha, group, factor1, factor2, factor3,  subject, data, "P", "P", "P", "P", paste(as.character(group),":",as.character(factor1), ":", as.character(factor2), ":", as.character(factor3)), nonparametric, ranked,varQGlobal )}
+  temp0 <- if(testing[1]) {hrm.1w.3f(X, alpha, group, factor1, factor2, factor3, subject, data, "P", "J", "J", "J",  paste(as.character(group) ), nonparametric, ranked,varQGlobal, np.correction )}
+  temp1 <- if(testing[2]) {hrm.1w.3f(X, alpha, group, factor1, factor2, factor3,  subject, data, "J", "P", "J", "J", paste(as.character(factor1)), nonparametric, ranked,varQGlobal, np.correction )}
+  temp2 <- if(testing[3]) {hrm.1w.3f(X, alpha, group, factor1, factor2, factor3,  subject, data, "J", "J", "P", "J", paste(as.character(factor2)), nonparametric, ranked,varQGlobal, np.correction )}
+  temp3 <- if(testing[4]) {hrm.1w.3f(X, alpha, group, factor1, factor2, factor3,  subject, data, "J", "J", "J", "P", paste(as.character(factor3)), nonparametric, ranked,varQGlobal, np.correction )}
+  temp4 <- if(testing[5]) {hrm.1w.3f(X, alpha, group, factor1, factor2, factor3,  subject, data, "P", "P", "J", "J", paste(as.character(group),":",as.character(factor1)), nonparametric, ranked,varQGlobal, np.correction )}
+  temp5 <- if(testing[6]) {hrm.1w.3f(X, alpha, group, factor1, factor2, factor3,  subject, data, "P", "J", "P", "J", paste(as.character(group),":",as.character(factor2)), nonparametric, ranked,varQGlobal, np.correction )}
+  temp6 <- if(testing[7]) {hrm.1w.3f(X, alpha, group, factor1, factor2, factor3,  subject, data, "P", "J", "J", "P", paste(as.character(group),":",as.character(factor3)), nonparametric, ranked,varQGlobal, np.correction )}
+  temp7 <- if(testing[8]) {hrm.1w.3f(X, alpha, group, factor1, factor2, factor3,  subject, data, "J", "P", "P", "J", paste(as.character(factor1),":",as.character(factor2)), nonparametric, ranked,varQGlobal, np.correction )}
+  temp8 <- if(testing[9]) {hrm.1w.3f(X, alpha, group, factor1, factor2, factor3,  subject, data, "J", "P", "J", "P", paste(as.character(factor1),":",as.character(factor3)), nonparametric, ranked,varQGlobal, np.correction )}
+  temp9 <- if(testing[10]) {hrm.1w.3f(X, alpha, group, factor1, factor2, factor3,  subject, data, "J", "J", "P", "P",paste(as.character(factor2),":",as.character(factor3)), nonparametric, ranked,varQGlobal, np.correction )}
+  temp10 <- if(testing[11]) {hrm.1w.3f(X, alpha, group, factor1, factor2, factor3,  subject, data, "P", "P", "P", "J", paste(as.character(group),":",as.character(factor1), ":", as.character(factor2)), nonparametric, ranked,varQGlobal, np.correction )}
+  temp11 <- if(testing[12]) {hrm.1w.3f(X, alpha, group, factor1, factor2, factor3,  subject, data, "P", "P", "J", "P", paste(as.character(group),":",as.character(factor1), ":", as.character(factor3)), nonparametric, ranked,varQGlobal, np.correction )}
+  temp12 <- if(testing[13]) {hrm.1w.3f(X, alpha, group, factor1, factor2, factor3,  subject, data, "P", "J", "P", "P", paste(as.character(group),":",as.character(factor2), ":", as.character(factor3)), nonparametric, ranked,varQGlobal, np.correction )}
+  temp13 <- if(testing[14]) {hrm.1w.3f(X, alpha, group, factor1, factor2, factor3,  subject, data, "J", "P", "P", "P", paste(as.character(factor1),":",as.character(factor2), ":", as.character(factor3)), nonparametric, ranked,varQGlobal, np.correction )}
+  temp14 <- if(testing[15]) {hrm.1w.3f(X, alpha, group, factor1, factor2, factor3,  subject, data, "P", "P", "P", "P", paste(as.character(group),":",as.character(factor1), ":", as.character(factor2), ":", as.character(factor3)), nonparametric, ranked,varQGlobal, np.correction )}
 
   output <- list()
   output$result <- rbind(temp0, temp1, temp2, temp3, temp4, temp5, temp6, temp7, temp8, temp9, temp10, temp11, temp12, temp13, temp14)
@@ -294,6 +313,8 @@ hrm.test.3.between <- function(X, alpha, group , factor1, factor2, factor3, subj
   output$data <- X
   output$var <- varQGlobal
   output$nonparametric <- nonparametric
+  output$np.correction <- correction
+  rownames(output$result) <- 1:dim(output$result)[1]
   class(output) <- "HRM"
   return (output)
 }
@@ -314,7 +335,7 @@ hrm.test.3.between <- function(X, alpha, group , factor1, factor2, factor3, subj
 #' @return \item{factors}{A list containing the whole- and subplot factors.}
 #' @return \item{data}{The data.frame or list containing the data.}
 #' @keywords internal
-hrm_test_internal <- function(formula, data, alpha = 0.05,  subject, nonparametric ){
+hrm_test_internal <- function(formula, data, alpha = 0.05,  subject, variable, nonparametric, np.correction){
 
   if(missing(data) || !is.data.frame(data)){
     stop("dataframe needed")
@@ -343,7 +364,7 @@ hrm_test_internal <- function(formula, data, alpha = 0.05,  subject, nonparametr
   }, warning = function(w) "", error = function(e) { paste("One of the factor columns could not be converted to a factor variable." ) } )
 
   dat <- model.frame(formula, data)
-  dat2 <- data.frame(dat,subj=data[,subject])
+  dat2 <- data.frame(dat,subj=data[,subject], variable_internal = data[, variable])
 
   m <- ncol(dat)
 
@@ -372,9 +393,16 @@ hrm_test_internal <- function(formula, data, alpha = 0.05,  subject, nonparametr
   wholeplot <- which(wholeplot==1)
   subplot <- which( subplot==1)
 
-
-  if(!(measurements == countSubplotFactor)){
-    stop(paste("The number of repeated measurements per subject (", measurements, ") is uneqal to the number of levels of the subplot factors (", countSubplotFactor, ")."))
+  if(is.null(variable)) {
+    if(!(measurements == countSubplotFactor)){
+      stop(paste("The number of repeated measurements per subject (", measurements, ") is uneqal to the number of levels of the subplot factors (", countSubplotFactor, ")."))
+    }
+  }
+  if(!is.null(variable)) {
+    p <- nlevels(dat2$variable_internal)
+    if(!(measurements/p == countSubplotFactor)){
+      stop(paste("The number of repeated measurements per subject (", measurements/p, ") is uneqal to the number of levels of the subplot factors (", countSubplotFactor, ")."))
+    }
   }
   if(length(wholeplot)>2){
     stop("Too many factors are used! Only two wholelot-factors are supported.")
@@ -391,6 +419,9 @@ hrm_test_internal <- function(formula, data, alpha = 0.05,  subject, nonparametr
   if(length(subplot)>5 & length(wholeplot)<1){
     stop("The model supports up to five subplot-factor when using no wholeplot-factors.")
   }
+  if((length(wholeplot) > 1  | length(subplot) > 1 ) & !is.null(variable)) {
+    stop("The package currently supports Multivariate Repeated Measures only for models with 1 whole-plot and 1 sub-plot factor.")
+  }
 
   # Case: no wholeplot, one subpot factor
   if(length(wholeplot) < 1 & length(subplot) == 1){
@@ -400,8 +431,11 @@ hrm_test_internal <- function(formula, data, alpha = 0.05,  subject, nonparametr
     subplot<-colnames(dat2[,subplot])
     X<-data
     data <- colnames(dat)[1]
-    return(hrm.test.1.one(X, alpha , factor1, subject, data, formula, nonparametric ))
-
+    if(is.null(variable)) {
+      return(hrm.test.1.one(X, alpha , factor1, subject, data, formula, nonparametric, np.correction ))
+    } else {
+      return(hrm.mv.1w.1f(X, alpha, NULL , factor1, subject, data, variable, formula, nonparametric ))
+    }
   }
 
   # Case: no wholeplot, two subpot factor
@@ -429,7 +463,7 @@ hrm_test_internal <- function(formula, data, alpha = 0.05,  subject, nonparametr
     subplot<-colnames(dat2[,subplot])
     X<-data
     data <- colnames(dat)[1]
-    return(hrm.test.2.two(X, alpha , factor1, factor2, subject, data, formula, testing, nonparametric ))
+    return(hrm.test.2.two(X, alpha , factor1, factor2, subject, data, formula, testing, nonparametric, np.correction ))
 
   }
 
@@ -469,7 +503,7 @@ hrm_test_internal <- function(formula, data, alpha = 0.05,  subject, nonparametr
     subplot<-colnames(dat2[,subplot])
     X<-data
     data <- colnames(dat)[1]
-    return(hrm.test.3.three(X, alpha , factor1, factor2, factor3, subject, data, formula, testing, nonparametric ))
+    return(hrm.test.3.three(X, alpha , factor1, factor2, factor3, subject, data, formula, testing, nonparametric, np.correction ))
 
   }
 
@@ -484,7 +518,7 @@ hrm_test_internal <- function(formula, data, alpha = 0.05,  subject, nonparametr
     subplot<-colnames(dat2[,subplot])
     X<-data
     data <- colnames(dat)[1]
-    return(hrm.test.4.four(X, alpha , factor1, factor2, factor3, factor4, subject, data, formula, testing = rep(1,2^4-1), nonparametric ))
+    return(hrm.test.4.four(X, alpha , factor1, factor2, factor3, factor4, subject, data, formula, testing = rep(1,2^4-1), nonparametric, np.correction ))
 
   }
 
@@ -499,7 +533,7 @@ hrm_test_internal <- function(formula, data, alpha = 0.05,  subject, nonparametr
     subplot<-colnames(dat2[,subplot])
     X<-data
     data <- colnames(dat)[1]
-    return(hrm.test.5.five(X, alpha , factor1, factor2, factor3, factor4, factor5, subject, data, formula, testing = rep(1,2^5-1), nonparametric ))
+    return(hrm.test.5.five(X, alpha , factor1, factor2, factor3, factor4, factor5, subject, data, formula, testing = rep(1,2^5-1), nonparametric, np.correction ))
 
   }
 
@@ -511,8 +545,11 @@ hrm_test_internal <- function(formula, data, alpha = 0.05,  subject, nonparametr
     wholeplot<-colnames(dat2[,group])
     X<-data
     data <- colnames(dat)[1]
-    return(hrm.test.1.none(X, alpha , group, subject, data, formula, nonparametric ))
-
+    if(is.null(variable)){
+      return(hrm.test.1.none(X, alpha , group, subject, data, formula, nonparametric ))
+    } else {
+      return(hrm.mv.1w.1f(X, alpha, group , NULL, subject, data, variable, formula, nonparametric ))
+    }
   }
 
   # Case: 1 whole and 1 subplot factor
@@ -543,7 +580,11 @@ hrm_test_internal <- function(formula, data, alpha = 0.05,  subject, nonparametr
     }
     X<-data
     data <- colnames(dat)[1]
-    return(hrm.test.2.one(X, alpha, group , factor1, subject, data, testing, formula, nonparametric ))
+    if(is.null(variable)) {
+      return(hrm.test.2.one(X, alpha, group , factor1, subject, data, testing, formula, nonparametric, np.correction ))
+    } else {
+      return(hrm.mv.1w.1f(X, alpha, group, factor1, subject, data, variable, formula, nonparametric))
+    }
   }
 
   # Case: 2 wholeplot, 1 subplot factor
@@ -590,7 +631,7 @@ hrm_test_internal <- function(formula, data, alpha = 0.05,  subject, nonparametr
     }
     X<-data
     data <- colnames(dat)[1]
-    return(hrm.test.2.between(X, alpha, group , subgroup, factor1, subject, data, testing, formula, nonparametric ))
+    return(hrm.test.2.between(X, alpha, group , subgroup, factor1, subject, data, testing, formula, nonparametric, np.correction ))
   }
 
   # Case: 1 wholeplot, 2 subplot factors
@@ -635,7 +676,7 @@ hrm_test_internal <- function(formula, data, alpha = 0.05,  subject, nonparametr
     }
     X<-data
     data <- colnames(dat)[1]
-    return(hrm.test.2.within(X, alpha, group , factor1, factor2, subject, data, testing, formula, nonparametric ))
+    return(hrm.test.2.within(X, alpha, group , factor1, factor2, subject, data, testing, formula, nonparametric, np.correction ))
   }
 
   # Case: 1 wholeplot, 3 subplot factors
@@ -724,7 +765,7 @@ hrm_test_internal <- function(formula, data, alpha = 0.05,  subject, nonparametr
     }
     X<-data
     data <- colnames(dat)[1]
-    return(hrm.test.3.between(X, alpha, group , factor1, factor2, factor3, subject, data, testing, formula, nonparametric ))
+    return(hrm.test.3.between(X, alpha, group , factor1, factor2, factor3, subject, data, testing, formula, nonparametric, np.correction ))
   }
 
 
@@ -805,6 +846,6 @@ hrm_test_internal <- function(formula, data, alpha = 0.05,  subject, nonparametr
     }
     X<-data
     data <- colnames(dat)[1]
-    return(hrm.test.2.between.within(X, alpha, group , subgroup, factor1, factor2, subject, data, testing, formula, nonparametric ))
+    return(hrm.test.2.between.within(X, alpha, group , subgroup, factor1, factor2, subject, data, testing, formula, nonparametric, np.correction ))
   }
 }
